GoBuilder class

Golang artifact builder

Constructors

GoBuilder({required String name, required String? assetName, required String bridgePath, List<String> sources = const [], List<String> dartBuildFiles = const []})

Properties

assetName → String?
Asset identifier.
final
bridgePath → String
Golang bridge to build.
final
dartBuildFiles → List<String>
The dart files involved in building this artifact.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the library to build.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources → List<String>
Sources to build the library.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required BuildConfig buildConfig, required BuildOutput buildOutput, required Logger? logger}) → Future<void>
Runs the Golang Compiler.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited