RunProcessResult class

Drop in replacement of ProcessResult.

Constructors

RunProcessResult({required int pid, required String command, required int exitCode, required String stderr, required String stdout})

Properties

command → String
final
exitCode → int
final
hashCode → int
The hash code for this object.
no setterinherited
pid → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → String
final
stdout → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited